@@ -37,6 +37,8 @@ import webbrowser
 import tkinter.filedialog
 import _thread
 
+from distutils.sysconfig import get_python_lib
+
 
 root=Tk()
 classes=('harmful','kitch','others','recyc')
@@ -51,21 +53,30 @@ a_accuracy=[]
 @ time :2021.11.10
 '''
 def check_files():
-    a=os.path.exists('model.py')
+    file000 = get_python_lib()
+    a = 0
+    path000 = os.path.join(file000, 'lry_test\\model.py')
+    a=os.path.exists(path000)
     if a == True:
         tkinter.messagebox.showinfo('提示','所有文件都可以被找到')
     else:
         tkinter.messagebox.showerror('错误', 'model.py文件缺失，重新安装本程序可能会解决问题')
 
 def fix_files():
-    a = os.path.exists('model.py')
+    file000 = get_python_lib()
+    a = 0
+    path000 = os.path.join(file000, 'lry_test\\model.py')
+    a = os.path.exists(path000)
     if a == True:
         tkinter.messagebox.showinfo('提示', '所有文件都可以被找到')
     else:
         tkinter.messagebox.showerror('错误', 'model.py文件缺失,并且无法被修复，也可以点击下方的按钮训练，重新安装本程序可能会解决问题')
 
 def Test_model_old():
-    a = os.path.exists('model.py')
+    file000 = get_python_lib()
+    a = 0
+    path000 = os.path.join(file000, 'lry_test\\model.py')
+    a = os.path.exists(path000)
     b=0
     if a == True:
         tkinter.messagebox.showinfo('提示', '所有文件都可以被找到')
@@ -113,8 +124,11 @@ def test_model(filepath):
             transforms.Normalize(mean=[0.485, 0.456, 0.406],
                                  std=[0.229, 0.224, 0.225])
         ])
+    file000 = get_python_lib()
+    a = 0
+    path000 = os.path.join(file000, 'lry_test\\model.py')
     if torch.cuda.is_available():
-        net = torch.load('model.py', map_location='cuda')
+        net = torch.load(path000, map_location='cuda')
         net = net.to(device)
         torch.no_grad()
         img = Im.open(filepath)
@@ -123,7 +137,7 @@ def test_model(filepath):
         outputs = net(img_)
         _, predicted = torch.max(outputs, 1)
     else:
-        net = torch.load('model.py', map_location='cpu')
+        net = torch.load(path000, map_location='cpu')
         net = net.to(device)
         torch.no_grad()
         img = Im.open(filepath)
@@ -262,7 +276,10 @@ def train():
                 best_acc = val_acc
                 torch.save(model.state_dict(), 'best_trans.mdl')
     print('best accuracy:', best_acc, 'best epoch:', (best_epoch + 1))
-    torch.save(model, 'model.py')
+    file000 = get_python_lib()
+    a = 0
+    path000 = os.path.join(file000, 'lry_test\\model.py')
+    torch.save(model, path000)
     print('loading model......')
     test_acc = evalute(model, test_loader)
     print('test accuracy:', test_acc)
@@ -334,20 +351,21 @@ class Data(Dataset):
         label=torch.tensor(label)
         return img,label
 
-
-a=0
+file000 = get_python_lib()
+a = 0
+path000=os.path.join(file000,'lry_test\\model.py')
 root.title('垃圾分类程序 version 10.0.0')
 root.geometry('1077x640')
-a_file=os.path.exists('model.py')
+a_file=os.path.exists('path000')
 if a==0:
     if a_file == True:
         a=a+1
     else:
         try:
-            os.rename('model.py','model.py')
+            #os.rename('C:\\model_lry\\model.py','C:\\model_lry\\model.py')
             a=a+1
         except:
-            tkinter.messagebox.showerror('错误', 'model.py文件缺失，重新安装本程序可能会解决问题')
+            #tkinter.messagebox.showerror('错误', 'C:\\model_lry\\model.py文件缺失，重新安装本程序可能会解决问题')
             a=a+1
 b1=Button(root,text='文件检查',height=3,width=18,command=check_files).place(x=100,y=20)
 b2=Button(root,text='文件缺失修复',height=3,width=18,command=fix_files).place(x=250,y=20)
